//-----------------------------------------------------------------------------
//    KAmodCOMBO example
//-----------------------------------------------------------------------------
//
//    THE SOFTWARE INCLUDED IN THIS FILE IS FOR GUIDANCE ONLY.
//    BTC KORPORACJA SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT
//    OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
//    FROM USE OF THIS SOFTWARE.
//
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
//  This sample works with ZL15AVR evaluation board.
//
//  This program scrolls 'StLEd316' text on LED displays, buttons S1..S8 turn
//  on and off LEDs, buttons S9..S16 switch LEDs brightness to max. or min.
//
//-----------------------------------------------------------------------------  
//  Connections:
//  For use with ZL15AVR only thing you need to do is connect modules Con1 
//  connector to ZL15AVR Con18 connector with IDC10 cable.
//
//  ZL15AVR      |   KAmodCOMBO
//  --------------------------
//  PD0 (Con18)  |   DIO (Con1)
//  PD1 (Con18)  |   CLS (Con1)
//  PD2 (Con18)  |   STB (Con1)
//  PD3 (Con18)  |   IRQ (Con1)
//
//
//-----------------------------------------------------------------------------
//  Fuse bits
//    Low; 0xCE 
//    High: 0x99
//-----------------------------------------------------------------------------



#define F_CPU 16000000UL
#include <util/delay.h>	
#include <avr/interrupt.h>
#include "KAmodCOMBO.h"

int k;

ISR(INT1_vect) 
{    
	unsigned char LEDs, Buttons1, Buttons2, LEDBrightness[8], i;

	//Read LED and button states
	STLED316_ReadLEDsAndButtons(&LEDs, &Buttons1, &Buttons2);

	// When button S1..S8 is pressed then turn on/off proper LED
	STLED316_SetLEDStates(LEDs ^ Buttons1);

	// When button S9..S16 is pressed then change brightness of proper LED
	STLED316_ReadLEDBrightness(LEDBrightness);

	// Change LED brightness
	for (i=0; i<8; i++) if (Buttons2 & (1 <<i))
	{
		if (LEDBrightness[i] == 0) LEDBrightness[i] = 0x7; else LEDBrightness[i] = 0;
	}
	STLED316_SetLEDBrightness(LEDBrightness);
	

}



int main(void)
{
	unsigned char j, Rot = 0;

	// STLEDText contains 'StLeD316  ' text encoded for LED display
	unsigned char STLEDText[10] = {
		STLED316_TOP_SEG | STLED316_MID_SEG | STLED316_BOT_SEG | STLED316_LT_SEG | STLED316_RB_SEG, // S
		STLED316_MID_SEG | STLED316_BOT_SEG | STLED316_LT_SEG  | STLED316_LB_SEG,  // t
		STLED316_BOT_SEG | STLED316_LT_SEG  | STLED316_LB_SEG, // L
		STLED316_TOP_SEG | STLED316_MID_SEG | STLED316_BOT_SEG | STLED316_LT_SEG  | STLED316_LB_SEG, // E
		STLED316_MID_SEG | STLED316_BOT_SEG | STLED316_LB_SEG | STLED316_RB_SEG | STLED316_RT_SEG, // d
		STLED316_TOP_SEG | STLED316_MID_SEG | STLED316_BOT_SEG | STLED316_RT_SEG | STLED316_RB_SEG, // 3
		STLED316_RT_SEG | STLED316_RB_SEG, // 1
		STLED316_TOP_SEG | STLED316_MID_SEG | STLED316_BOT_SEG | STLED316_LB_SEG | STLED316_LT_SEG | STLED316_RB_SEG,// 6
		0, 0
	};
	
    
    sei();       



	STLED316_Initialize();
	STLED316_DisplayOn();
	
	// Set variable brightness control (every LED display and LED can have different brightness)
	STLED316_SetBrghtCtrlModeAndDigitCnt(STLED316_BRGHT_MODE_VAR, 0, 6);
	
	// Set max. brightness for LED displays
	STLED316_7Seg_SetBrghtInd(0, 7, 7);
	STLED316_7Seg_SetBrghtInd(2, 7, 7);
	STLED316_7Seg_SetBrghtInd(5, 7, 7);


	while(1)
	{
		// Turn off INT1 to avoid communication problems
		GIMSK &= ~(1<<INT1);
		// Write text to LED displays
		for (j=0; j<6; j++) STLED316_7Seg_Write(5-j, STLEDText[(j + Rot) % 10] | (Rot % 2 == 0 ? STLED316_DOT_SEG : 0));
		Rot++;

		// Turn on INT1
		GIMSK |= (1<<INT1);

		_delay_ms(1000);
	}
}
